@@ -1,13 +1,14 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2023 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Marc R. Hoffmann - initial API and implementation
- *    
+ *
  *******************************************************************************/
 package org.jacoco.core.instr;
 
@@ -25,20 +26,21 @@ import java.io.ObjectOutputStream;
 import java.io.OutputStream;
 import java.io.Serializable;
 import java.util.Arrays;
-import java.util.jar.JarInputStream;
-import java.util.jar.JarOutputStream;
-import java.util.jar.Pack200;
+import java.util.zip.CRC32;
 import java.util.zip.GZIPInputStream;
 import java.util.zip.GZIPOutputStream;
 import java.util.zip.ZipEntry;
 import java.util.zip.ZipInputStream;
 import java.util.zip.ZipOutputStream;
 
+import org.jacoco.core.JaCoCo;
 import org.jacoco.core.analysis.AnalyzerTest;
+import org.jacoco.core.internal.Pack200Streams;
 import org.jacoco.core.internal.data.CRC64;
 import org.jacoco.core.internal.instr.InstrSupport;
 import org.jacoco.core.runtime.IExecutionDataAccessorGenerator;
 import org.jacoco.core.test.TargetLoader;
+import org.junit.AssumptionViolatedException;
 import org.junit.Before;
 import org.junit.Test;
 import org.objectweb.asm.ClassWriter;
@@ -98,7 +100,7 @@ public class InstrumenterTest {
 	@Test
 	public void should_not_modify_class_bytes_to_support_next_version()
 			throws Exception {
-		final byte[] originalBytes = createClass(Opcodes.V12 + 1);
+		final byte[] originalBytes = createClass(Opcodes.V20 + 1);
 		final byte[] bytes = new byte[originalBytes.length];
 		System.arraycopy(originalBytes, 0, bytes, 0, originalBytes.length);
 		final long expectedClassId = CRC64.classId(bytes);
@@ -116,6 +118,22 @@ public class InstrumenterTest {
 		return cw.toByteArray();
 	}
 
+	/**
+	 * @see #instrumentAll_should_throw_exception_for_unsupported_class_file_version()
+	 */
+	@Test
+	public void instrument_should_throw_exception_for_unsupported_class_file_version() {
+		final byte[] bytes = createClass(Opcodes.V20 + 2);
+		try {
+			instrumenter.instrument(bytes, "UnsupportedVersion");
+			fail("exception expected");
+		} catch (final IOException e) {
+			assertExceptionMessage("UnsupportedVersion", e);
+			assertEquals("Unsupported class file major version 66",
+					e.getCause().getMessage());
+		}
+	}
+
 	@Test
 	public void testInstrumentClass() throws Exception {
 		byte[] bytes = instrumenter.instrument(
@@ -138,8 +156,7 @@ public class InstrumenterTest {
 			instrumenter.instrument(brokenclass, "Broken.class");
 			fail();
 		} catch (IOException e) {
-			assertEquals("Error while instrumenting Broken.class.",
-					e.getMessage());
+			assertExceptionMessage("Broken.class", e);
 		}
 	}
 
@@ -160,8 +177,7 @@ public class InstrumenterTest {
 			instrumenter.instrument(new BrokenInputStream(), "BrokenStream");
 			fail("exception expected");
 		} catch (IOException e) {
-			assertEquals("Error while instrumenting BrokenStream.",
-					e.getMessage());
+			assertExceptionMessage("BrokenStream", e);
 		}
 	}
 
@@ -176,8 +192,7 @@ public class InstrumenterTest {
 					new ByteArrayOutputStream(), "BrokenStream");
 			fail("exception expected");
 		} catch (IOException e) {
-			assertEquals("Error while instrumenting BrokenStream.",
-					e.getMessage());
+			assertExceptionMessage("BrokenStream", e);
 		}
 	}
 
@@ -196,11 +211,28 @@ public class InstrumenterTest {
 		new ObjectOutputStream(buffer).writeObject(obj1);
 
 		// Deserialize with original class definition:
-		Object obj2 = new ObjectInputStream(new ByteArrayInputStream(
-				buffer.toByteArray())).readObject();
+		Object obj2 = new ObjectInputStream(
+				new ByteArrayInputStream(buffer.toByteArray())).readObject();
 		assertEquals("Hello42", obj2.toString());
 	}
 
+	/**
+	 * @see #instrument_should_throw_exception_for_unsupported_class_file_version()
+	 */
+	@Test
+	public void instrumentAll_should_throw_exception_for_unsupported_class_file_version() {
+		final byte[] bytes = createClass(Opcodes.V20 + 2);
+		try {
+			instrumenter.instrumentAll(new ByteArrayInputStream(bytes),
+					new ByteArrayOutputStream(), "UnsupportedVersion");
+			fail("exception expected");
+		} catch (final IOException e) {
+			assertExceptionMessage("UnsupportedVersion", e);
+			assertEquals("Unsupported class file major version 66",
+					e.getCause().getMessage());
+		}
+	}
+
 	@Test
 	public void testInstrumentAll_Class() throws IOException {
 		InputStream in = TargetLoader.getClassData(getClass());
@@ -215,18 +247,38 @@ public class InstrumenterTest {
 	public void testInstrumentAll_Zip() throws IOException {
 		ByteArrayOutputStream buffer = new ByteArrayOutputStream();
 		ZipOutputStream zipout = new ZipOutputStream(buffer);
-		zipout.putNextEntry(new ZipEntry("Test.class"));
+
+		// Compressed Entry
+		ZipEntry entry = new ZipEntry("TestCompressed.class");
+		entry.setMethod(ZipEntry.DEFLATED);
+		zipout.putNextEntry(entry);
 		zipout.write(TargetLoader.getClassDataAsBytes(getClass()));
+
+		// Uncompressed Entry
+		entry = new ZipEntry("TestUncompressed.class");
+		entry.setMethod(ZipEntry.STORED);
+		entry.setSize(TargetLoader.getClassDataAsBytes(getClass()).length);
+		CRC32 crc = new CRC32();
+		crc.update(TargetLoader.getClassDataAsBytes(getClass()));
+		entry.setCrc(crc.getValue());
+		zipout.putNextEntry(entry);
+		zipout.write(TargetLoader.getClassDataAsBytes(getClass()));
+
 		zipout.finish();
 		ByteArrayOutputStream out = new ByteArrayOutputStream();
 
 		int count = instrumenter.instrumentAll(
 				new ByteArrayInputStream(buffer.toByteArray()), out, "Test");
 
-		assertEquals(1, count);
-		ZipInputStream zipin = new ZipInputStream(new ByteArrayInputStream(
-				out.toByteArray()));
-		assertEquals("Test.class", zipin.getNextEntry().getName());
+		assertEquals(2, count);
+		ZipInputStream zipin = new ZipInputStream(
+				new ByteArrayInputStream(out.toByteArray()));
+		entry = zipin.getNextEntry();
+		assertEquals("TestCompressed.class", entry.getName());
+		assertEquals(ZipEntry.DEFLATED, entry.getMethod());
+		entry = zipin.getNextEntry();
+		assertEquals("TestUncompressed.class", entry.getName());
+		assertEquals(ZipEntry.STORED, entry.getMethod());
 		assertNull(zipin.getNextEntry());
 	}
 
@@ -241,7 +293,7 @@ public class InstrumenterTest {
 					new ByteArrayOutputStream(), "Broken");
 			fail("exception expected");
 		} catch (IOException e) {
-			assertEquals("Error while instrumenting Broken.", e.getMessage());
+			assertExceptionMessage("Broken", e);
 		}
 	}
 
@@ -268,7 +320,7 @@ public class InstrumenterTest {
 			instrumenter.instrumentAll(inputStream, new ByteArrayOutputStream(),
 					"Broken");
 		} catch (IOException e) {
-			assertEquals("Error while instrumenting Broken.", e.getMessage());
+			assertExceptionMessage("Broken", e);
 		}
 	}
 
@@ -290,7 +342,7 @@ public class InstrumenterTest {
 					new ByteArrayOutputStream(), "Test.zip");
 			fail("exception expected");
 		} catch (IOException e) {
-			assertEquals("Error while instrumenting Test.zip.", e.getMessage());
+			assertExceptionMessage("Test.zip", e);
 		}
 	}
 
@@ -315,9 +367,7 @@ public class InstrumenterTest {
 					new ByteArrayOutputStream(), "broken.zip");
 			fail("exception expected");
 		} catch (IOException e) {
-			assertEquals(
-					"Error while instrumenting broken.zip@brokenentry.txt.",
-					e.getMessage());
+			assertExceptionMessage("broken.zip@brokenentry.txt", e);
 		}
 	}
 
@@ -338,8 +388,7 @@ public class InstrumenterTest {
 					"test.zip");
 			fail();
 		} catch (IOException e) {
-			assertEquals("Error while instrumenting test.zip@Test.class.",
-					e.getMessage());
+			assertExceptionMessage("test.zip@Test.class", e);
 		}
 	}
 
@@ -356,12 +405,19 @@ public class InstrumenterTest {
 					new ByteArrayOutputStream(), "Test.gz");
 			fail("exception expected");
 		} catch (IOException e) {
-			assertEquals("Error while instrumenting Test.gz.", e.getMessage());
+			assertExceptionMessage("Test.gz", e);
 		}
 	}
 
 	@Test
 	public void testInstrumentAll_Pack200() throws IOException {
+		try {
+			Class.forName("java.util.jar.Pack200");
+		} catch (ClassNotFoundException e) {
+			throw new AssumptionViolatedException(
+					"this test requires JDK with Pack200");
+		}
+
 		ByteArrayOutputStream jarbuffer = new ByteArrayOutputStream();
 		ZipOutputStream zipout = new ZipOutputStream(jarbuffer);
 		zipout.putNextEntry(new ZipEntry("Test.class"));
@@ -370,23 +426,18 @@ public class InstrumenterTest {
 
 		ByteArrayOutputStream pack200buffer = new ByteArrayOutputStream();
 		GZIPOutputStream gzipOutput = new GZIPOutputStream(pack200buffer);
-		Pack200.newPacker().pack(
-				new JarInputStream(new ByteArrayInputStream(
-						jarbuffer.toByteArray())), gzipOutput);
+		Pack200Streams.pack(jarbuffer.toByteArray(), gzipOutput);
 		gzipOutput.finish();
 
 		ByteArrayOutputStream out = new ByteArrayOutputStream();
-		int count = instrumenter.instrumentAll(new ByteArrayInputStream(
-				pack200buffer.toByteArray()), out, "Test");
-
-		jarbuffer.reset();
-		Pack200.newUnpacker()
-				.unpack(new GZIPInputStream(new ByteArrayInputStream(
-						out.toByteArray())), new JarOutputStream(jarbuffer));
+		int count = instrumenter.instrumentAll(
+				new ByteArrayInputStream(pack200buffer.toByteArray()), out,
+				"Test");
 
 		assertEquals(1, count);
-		ZipInputStream zipin = new ZipInputStream(new ByteArrayInputStream(
-				jarbuffer.toByteArray()));
+		ZipInputStream zipin = new ZipInputStream(
+				Pack200Streams.unpack(new GZIPInputStream(
+						new ByteArrayInputStream(out.toByteArray()))));
 		assertEquals("Test.class", zipin.getNextEntry().getName());
 		assertNull(zipin.getNextEntry());
 	}
@@ -404,8 +455,7 @@ public class InstrumenterTest {
 			instrumenter.instrumentAll(new ByteArrayInputStream(buffer),
 					new ByteArrayOutputStream(), "Test.pack200");
 		} catch (IOException e) {
-			assertEquals("Error while instrumenting Test.pack200.",
-					e.getMessage());
+			assertExceptionMessage("Test.pack200", e);
 		}
 	}
 
@@ -433,8 +483,8 @@ public class InstrumenterTest {
 				new ByteArrayInputStream(buffer.toByteArray()), out, "Test");
 
 		assertEquals(0, count);
-		ZipInputStream zipin = new ZipInputStream(new ByteArrayInputStream(
-				out.toByteArray()));
+		ZipInputStream zipin = new ZipInputStream(
+				new ByteArrayInputStream(out.toByteArray()));
 		assertEquals("META-INF/MANIFEST.MF", zipin.getNextEntry().getName());
 		assertNull(zipin.getNextEntry());
 	}
@@ -452,10 +502,16 @@ public class InstrumenterTest {
 				new ByteArrayInputStream(buffer.toByteArray()), out, "Test");
 
 		assertEquals(0, count);
-		ZipInputStream zipin = new ZipInputStream(new ByteArrayInputStream(
-				out.toByteArray()));
+		ZipInputStream zipin = new ZipInputStream(
+				new ByteArrayInputStream(out.toByteArray()));
 		assertEquals("META-INF/ALIAS.SF", zipin.getNextEntry().getName());
 		assertNull(zipin.getNextEntry());
 	}
 
+	private void assertExceptionMessage(String name, Exception ex) {
+		String expected = "Error while instrumenting " + name + " with JaCoCo "
+				+ JaCoCo.VERSION + "/" + JaCoCo.COMMITID_SHORT + ".";
+		assertEquals(expected, ex.getMessage());
+	}
+
 }
