@@ -1,13 +1,14 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2023 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Marc R. Hoffmann - initial API and implementation
- *    
+ *
  *******************************************************************************/
 package org.jacoco.core.internal.instr;
 
@@ -111,14 +112,12 @@ public class SignatureRemoverTest {
 				+ "Name: org/jacoco/example/B.class\r\n" //
 				+ "OtherInfo: keep this\r\n" //
 				+ "\r\n";
-		assertEquals(
-				createManifest(expected.getBytes("ISO-8859-1")),
+		assertEquals(createManifest(expected.getBytes("ISO-8859-1")),
 				createManifest(out.toByteArray()));
 	}
 
 	private static Manifest createManifest(final byte[] bytes)
 			throws IOException {
-		return new Manifest(
-				new ByteArrayInputStream(bytes));
+		return new Manifest(new ByteArrayInputStream(bytes));
 	}
 }
