@@ -1,13 +1,14 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2023 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Marc R. Hoffmann - initial API and implementation
- *    
+ *
  *******************************************************************************/
 package org.jacoco.report.xml;
 
@@ -191,8 +192,7 @@ public class XMLFormatterTest {
 		assertPathMatches("1", "count(/report/package[@name='empty']/class)");
 		assertPathMatches("empty/Empty",
 				"/report/package[@name='empty']/class/@name");
-		assertPathMatches("0",
-				"count(report/package[@name='empty']/class/*)");
+		assertPathMatches("0", "count(report/package[@name='empty']/class/*)");
 
 		assertPathMatches("1",
 				"count(/report/package[@name='empty']/sourcefile)");
